==> simple_survey-8.x-1.0-rc4.tar.gz: simple_survey/src/Form/SurveyQuestionForm.php <==
<?php

namespace Drupal\simple_survey\Form;

use Drupal\Component\Utility\Xss;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Entity\ContentEntityForm;
use Drupal\simple_survey\Entity\SimpleSurvey;

/**
 * Class ContentEntityExampleSettingsForm.
 *
 * @package Drupal\simple_survey\Form
 *
 * @ingroup simple_survey
 */
class SurveyQuestionForm extends ContentEntityForm {

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state) {
    $status = parent::save($form, $form_state);

    $entity = $this->entity;
    if ($status == SAVED_UPDATED) {
      drupal_set_message($this->t('The survey question %feed has been updated.', [
        '%feed' => $entity->get('question')->getValue(),
      ]));
    }
    else {
      drupal_set_message($this->t('The survey question %feed has been added.', [
        '%feed' => $entity->get('question')->getValue(),
      ]));
    }

    $form_state->setRedirect('entity.simple_survey.edit_form', [
      'simple_survey' => $entity->survey->entity->id(),
    ]);

    return $status;
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, SimpleSurvey $simple_survey = NULL) {
    $form = parent::buildForm($form, $form_state);
    $moduleHandler = \Drupal::service('module_handler');

    $survey_question = $this->entity;

    $form['#title'] = $this->t('%simple_survey_label - %survey_question', [
      '%simple_survey_label' => $simple_survey->label(),
      '%survey_question' => Xss::filter($survey_question->question->value),
    ]);

    $form['question_tabs'] = [
      '#type' => $moduleHandler->moduleExists('field_group') ? 'horizontal_tabs' : 'vertical_tabs',
      '#tree' => TRUE,
      '#group_name' => 'question_tabs',
    ];

    $form['question_entry'] = [
      '#type' => 'details',
      '#title' => $this->t('Question Entry'),
      '#collapsible' => TRUE,
      '#collapsed' => FALSE,
      '#group' => 'question_tabs',
      '#group_name' => 'question_entry',
    ];

    $form['input_configuration'] = [
      '#type' => 'details',
      '#title' => $this->t('Input Configuration'),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
      '#group' => 'question_tabs',
      '#group_name' => 'question_entry',
      '#states' => [
        'visible' => [
          ':input[name="question_type"]' => ['value' => 'normal'],
        ],
      ],
    ];

    $form['question']['#group'] = 'question_entry';
    $form['question_disclaimer']['#group'] = 'question_entry';
    $form['question_type']['#group'] = 'question_entry';
    $form['next_question']['#group'] = 'question_entry';

    $form['input_type']['#group'] = 'input_configuration';
    $form['input_type']['#states'] = [
      'enabled' => [
        ':input[name="question_type"]' => ['value' => 'normal'],
      ],
    ];

    $form['display_as']['#group'] = 'input_configuration';
    $form['display_as']['#states'] = [
      'enabled' => [
        ':input[name="question_type"]' => ['value' => 'normal'],
      ],
      'visible' => [
        [
          ':input[name="input_type"]' => ['value' => 'checkbox'],
        ],
        [
          ':input[name="input_type"]' => ['value' => 'radio'],
        ],
      ],
    ];

    $form['placeholder_text']['#group'] = 'input_configuration';
    $form['placeholder_text']['#states'] = [
      'enabled' => [
        ':input[name="question_type"]' => ['value' => 'normal'],
      ],
      'visible' => [
        [
          ':input[name="input_type"]' => ['value' => 'textArea'],
        ],
        [
          ':input[name="input_type"]' => ['value' => 'text'],
        ],
      ],
    ];

    $form['options']['#group'] = 'input_configuration';
    $form['options']['#states'] = [
      'enabled' => [
        ':input[name="question_type"]' => ['value' => 'normal'],
      ],
      'visible' => [
        [
          ':input[name="input_type"]' => ['value' => 'checkbox'],
        ],
        [
          ':input[name="input_type"]' => ['value' => 'radio'],
        ],
        [
          ':input[name="input_type"]' => ['value' => 'select'],
        ],
      ],
    ];

    $form['branching']['#name'] = 'branching';
    $form['branching']['#group'] = 'input_configuration';
    $form['branching']['#states'] = [
      'enabled' => [
        ':input[name="question_type"]' => ['value' => 'normal'],
      ],
      'visible' => [
        [
          ':input[name="input_type"]' => ['value' => 'checkbox'],
        ],
        [
          ':input[name="input_type"]' => ['value' => 'radio'],
        ],
        [
          ':input[name="input_type"]' => ['value' => 'select'],
        ],
      ],
    ];

    $form['survey']['#disabled'] = TRUE;

    if ($this->entity->isNew()) {
      $form['survey']['widget']['#default_value'] = $simple_survey->id();
    }

    return $form;
  }

}

==> simple_survey-8.x-1.10.tar.gz: simple_survey/src/Form/SurveyQuestionForm.php <==
<?php

namespace Drupal\simple_survey\Form;

use Drupal\Component\Utility\Xss;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Entity\ContentEntityForm;
use Drupal\simple_survey\Entity\SimpleSurvey;

/**
 * Class ContentEntityExampleSettingsForm.
 *
 * @package Drupal\simple_survey\Form
 *
 * @ingroup simple_survey
 */
class SurveyQuestionForm extends ContentEntityForm {

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state) {
    $status = parent::save($form, $form_state);

    $entity = $this->entity;

    $message = $this->t('The survey question %feed has been added.', [
      '%feed' => $entity->get('question')->getValue(),
    ]);

    if ($status == SAVED_UPDATED) {
      $message = $this->t('The survey question %feed has been updated.', [
        '%feed' => $entity->get('question')->getValue(),
      ]);
    }

    $this->messenger()->addStatus($message);

    $form_state->setRedirect('entity.simple_survey.edit_form', [
      'simple_survey' => $entity->survey->entity->id(),
    ]);

    return $status;
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, SimpleSurvey $simple_survey = NULL) {
    $form = parent::buildForm($form, $form_state);
    $moduleHandler = \Drupal::service('module_handler');

    $survey_question = $this->entity;

    $form['#title'] = $this->t('%simple_survey_label - %survey_question', [
      '%simple_survey_label' => $simple_survey->label(),
      '%survey_question' => Xss::filter($survey_question->question->value),
    ]);

    $form['question_tabs'] = [
      '#type' => $moduleHandler->moduleExists('field_group') ? 'horizontal_tabs' : 'vertical_tabs',
      '#tree' => TRUE,
      '#group_name' => 'question_tabs',
    ];

    $form['question_entry'] = [
      '#type' => 'details',
      '#title' => $this->t('Question Entry'),
      '#collapsible' => TRUE,
      '#collapsed' => FALSE,
      '#group' => 'question_tabs',
      '#group_name' => 'question_entry',
    ];

    $form['input_configuration'] = [
      '#type' => 'details',
      '#title' => $this->t('Input Configuration'),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
      '#group' => 'question_tabs',
      '#group_name' => 'question_entry',
      '#states' => [
        'visible' => [
          ':input[name="question_type"]' => ['value' => 'normal'],
        ],
      ],
    ];

    $form['question']['#group'] = 'question_entry';
    $form['question_disclaimer']['#group'] = 'question_entry';
    $form['question_type']['#group'] = 'question_entry';
    $form['next_question']['#group'] = 'question_entry';

    $form['input_type']['#group'] = 'input_configuration';
    $form['input_type']['#states'] = [
      'enabled' => [
        ':input[name="question_type"]' => ['value' => 'normal'],
      ],
    ];

    $form['display_as']['#group'] = 'input_configuration';
    $form['display_as']['#states'] = [
      'enabled' => [
        ':input[name="question_type"]' => ['value' => 'normal'],
      ],
      'visible' => [
        [
          ':input[name="input_type"]' => ['value' => 'checkbox'],
        ],
        [
          ':input[name="input_type"]' => ['value' => 'radio'],
        ],
      ],
    ];

    $form['placeholder_text']['#group'] = 'input_configuration';
    $form['placeholder_text']['#states'] = [
      'enabled' => [
        ':input[name="question_type"]' => ['value' => 'normal'],
      ],
      'visible' => [
        [
          ':input[name="input_type"]' => ['value' => 'textArea'],
        ],
        [
          ':input[name="input_type"]' => ['value' => 'text'],
        ],
      ],
    ];

    $form['options']['#group'] = 'input_configuration';
    $form['options']['#states'] = [
      'enabled' => [
        ':input[name="question_type"]' => ['value' => 'normal'],
      ],
      'visible' => [
        [
          ':input[name="input_type"]' => ['value' => 'checkbox'],
        ],
        [
          ':input[name="input_type"]' => ['value' => 'radio'],
        ],
        [
          ':input[name="input_type"]' => ['value' => 'select'],
        ],
      ],
    ];

    $form['branching']['#name'] = 'branching';
    $form['branching']['#group'] = 'input_configuration';
    $form['branching']['#states'] = [
      'enabled' => [
        ':input[name="question_type"]' => ['value' => 'normal'],
      ],
      'visible' => [
        [
          ':input[name="input_type"]' => ['value' => 'checkbox'],
        ],
        [
          ':input[name="input_type"]' => ['value' => 'radio'],
        ],
        [
          ':input[name="input_type"]' => ['value' => 'select'],
        ],
      ],
    ];

    $form['survey']['#disabled'] = TRUE;

    if ($this->entity->isNew()) {
      $form['survey']['widget']['#default_value'] = $simple_survey->id();
    }

    return $form;
  }

}
